/*
 *    Server.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl.hli;

import org.nzdl.gsdl.service.*;
import org.nzdl.gsdl.corba.gsdlInterface.*;
import org.nzdl.gsdl.util.*;


// java standard library classes used
import java.io.IOException;
import java.io.Serializable;
import java.lang.Cloneable;
import java.util.Vector;
import java.util.Set;
import java.util.Iterator;
import java.util.Enumeration;

/**
 * A high level view of a digital library server.
 *
 *
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2220 $
 * @see Collection
 * @see Document
 * @see
 */

public class Server implements Cloneable, Serializable
{
  /** The host running the server. Currently broken. */
  String host = "";
  /** The host running the server. Currently broken. */
  public String getHost() { return host; };
  /** The host running the server. Currently broken. */
  public void setHost(String str) { host = str; };

  /** The Independant Object Reference for this Server */
  String IOR = "";
  /** The Independant Object Reference for this Server */
  public String getIOR() { return IOR; };
  /** The Independant Object Reference for this Server */
  public void setIOR(String str) { IOR = str; };

  /** The collections offered by this server */
  Vector collections = null;
  /** The collections offered by this server */
  public Vector getCollections() {
    return new Vector(collections);
  }
  /** The underlying interface */
  NzdlService nzdl = null;

  /** Initialise (or re-initialise) the Server */
  public void update() {
    //construct a new interface
    if (IOR != null && IOR != "") 
      nzdl = NzdlServiceFactory.createNzdlService(IOR);
    if (nzdl == null)
      throw new Error("Null NzdlService");

    // clear the collection set
    if (collections != null)
      collections.clear();
    collections = new Vector();

    // restock the collection set
    Set set = nzdl.getCollectionSet();
    if (set == null)
      throw new Error("getCollectionSet() returned null");
    Iterator iter = set.iterator() ;
    if (iter == null)
      throw new Error("iterator() returned null");
    while(iter.hasNext()) {
      String name = (String) iter.next();
      NzdlCollectionInfo info = nzdl.getCollectionInfo(name);
      Collection collection = new Collection(this,name,info); 
      collections.add(collection);
    }
  }

  /** Find a collection based on it's name */
  public Collection collectionForName(String name) {
    Enumeration e =  collections.elements();
    while(e.hasMoreElements()) {
      Collection collection = (Collection) e.nextElement(); 
      if (collection!= null && collection.getName().equals(name)) {
	return collection;
      }
    }
    return null;
  }
  /** Build a new Server */
  public Server(NzdlService nzdl) {
    this.nzdl = nzdl;
    update();
  }

  /** Build a new Server */
  public Server(String IOR) {
    this.IOR = IOR;
    update();
  }

  public static void main(String args[]) throws IOException
  {
    NzdlService nzdl= NzdlServiceFactory.findIOR(args,null,null,null,null);
    Server server = new Server(nzdl); 
  }

}











